@@ -1,9 +1,8 @@
-import datetime
 import logging
 
-from django.db.models import JSONField
 from django.db import connections
-from django.db.models import Model, DateTimeField, Manager, CharField, TextField
+from django.db.models import JSONField
+from django.db.models import Model, DateTimeField, Manager, TextField, GenericIPAddressField
 from django.utils import timezone
 
 from isc_common.auth.models.user import User
@@ -85,7 +84,7 @@ class History(Model):
     username = NameField()
     fio = NameField()
     data = JSONField(default=dict)
-    ip_address = CharField(max_length=20)
+    ip_address = GenericIPAddressField()
     user_agent = TextField()
 
     objects = HistoryManager()
