@@ -104,7 +104,7 @@ def str_to_bool(s):
 
 
 def bool_to_jsBool(value):
-    if value is True:
+    if value == True:
         return "true"
     return "false"
 
@@ -237,7 +237,7 @@ class Stack:
 
     def push(self, item, exists_function=None, logger=None):
         if callable(exists_function):
-            if exists_function(item) is False:
+            if exists_function(item) == False:
                 self.stack.append(item)
                 if isinstance(logger, Logger):
                     logger.debug(f'self.stack.append: {item}')
