@@ -34,7 +34,7 @@ def blinkString(text, blink=True, color="black", bold=False) -> Text:
     else:
         res = f'<div><strong><font color="{color}"</font>{text}</strong></div>'
 
-    if bold is True:
+    if bold == True:
         return f'<b>{res}</b>'
     else:
         return res
