@@ -42,7 +42,7 @@ class Body:
         else:
             body = BytesToJson(body)
         self.body = BodyWrapper(**body)
-        if self.body.transaction is not None:
+        if self.body.transaction != None:
             operations = self.body.transaction.get('operations')
             if isinstance(operations, list):
                 for operation in operations:
@@ -52,38 +52,38 @@ class Body:
                         self.body.httpHeaders = httpHeaders
                         break
 
-        if self.body.httpHeaders is not None:
+        if self.body.httpHeaders != None:
             self.body.httpHeaders = Wrapper(**self.body.httpHeaders)
-        elif self.body.data is not None and self.body.data.get('httpHeaders') is not None:
+        elif self.body.data != None and self.body.data.get('httpHeaders') != None:
             self.body.httpHeaders = Wrapper(**self.body.data.get('httpHeaders'))
 
     @property
     def login(self):
         from isc_common.auth.models.user import User
-        if self.body.login is not None:
+        if self.body.login != None:
             return self.body.login
-        elif self.body.httpHeaders is not None and self.body.httpHeaders.USER_ID:
+        elif self.body.httpHeaders != None and self.body.httpHeaders.USER_ID:
             return User.objects.get(id=self.body.httpHeaders.USER_ID).username
         else:
-            if self.session is not None and self.session._session is not None:
+            if self.session != None and self.session._session != None:
                 return self.session._session.get('ws_channel').split('_')[1]
             raise Exception('user not enable type')
 
     @property
     def user(self):
         from isc_common.auth.models.user import User
-        if self.body.login is not None:
+        if self.body.login != None:
             try:
                 return User.objects.get(username=self.body.login)
             except User.DoesNotExist:
                 raise Exception('user not enable type')
-        elif self.body.httpHeaders is not None and self.body.httpHeaders.USER_ID:
+        elif self.body.httpHeaders != None and self.body.httpHeaders.USER_ID:
             return User.objects.get(id=self.body.httpHeaders.USER_ID)
         else:
-            if self.session is not None and self.session._session is not None:
+            if self.session != None and self.session._session != None:
                 try:
                     ws_channel = self.session._session.get('ws_channel')
-                    if ws_channel is not None:
+                    if ws_channel != None:
                         return User.objects.get(username=self.session._session.get('ws_channel').split('_')[1])
                     else:
                         return None
@@ -123,26 +123,26 @@ def JsonWSResponseWithException(printing=False, printing_res=False):
                 request = args[0]
 
                 self.port = request.GET.get('ws_port')
-                if self.port is None:
+                if self.port == None:
                     self.port = request.GET.get('port')
-                    if self.port is None:
+                    if self.port == None:
                         self.port = settings.WS_PORT
-                        if self.port is None:
+                        if self.port == None:
                             raise Exception_WS_Enabled(Common.arraund_error('Do not have ws_port'))
 
                 self.host = request.GET.get('ws_host')
-                if self.host is None:
+                if self.host == None:
                     self.host = request.GET.get('host')
-                    if self.host is None:
+                    if self.host == None:
                         self.host = settings.WS_HOST
-                        if self.host is None:
+                        if self.host == None:
                             raise Exception_WS_Enabled(Common.arraund_error('Do not have ws_host'))
 
                 self.channel = request.GET.get('ws_channel')
-                if self.channel is None:
+                if self.channel == None:
                     body = BytesToJson(request.body)
                     body = Body(body, request.session)
-                    if settings.WS_CHANNEL is not None:
+                    if settings.WS_CHANNEL != None:
                         self.channel = f'''{settings.WS_CHANNEL}_{body.login}'''
 
                 try:
@@ -273,24 +273,24 @@ def JsonWSPostResponseWithException(printing=False, printing_res=False):
             request = args[0]
 
             self.port = request.POST.get('ws_port')
-            if self.port is None:
+            if self.port == None:
                 self.port = settings.WS_PORT
                 if not self.port:
                     raise Exception(Common.arraund_error('Do not have ws_port'))
 
             self.host = request.POST.get('ws_host')
-            if self.host is None:
+            if self.host == None:
                 self.host = settings.WS_HOST
                 if not self.host:
                     raise Exception(Common.arraund_error('Do not have ws_host'))
 
             self.channel = request.POST.get('ws_channel')
-            if self.channel is None:
+            if self.channel == None:
                 body = BytesToJson(request.body)
                 body = Body(body, request.session)
-                if settings.WS_CHANNEL is not None:
+                if settings.WS_CHANNEL != None:
                     self.channel = f'''{settings.WS_CHANNEL}_{body.login}'''
-                    if self.channel is None:
+                    if self.channel == None:
                         raise Exception(Common.arraund_error('Do not have ws_channel'))
 
             try:
@@ -392,7 +392,7 @@ class DSResponse(RPCResponse):
 
         if isinstance(data, list):
 
-            if self.startRow is not None and self.endRow is not None:
+            if self.startRow != None and self.endRow != None:
                 qty = self.endRow - self.startRow
                 len_data = len(self.data)
 
