@@ -235,7 +235,7 @@ class CommonQuerySet(QuerySet):
     def getValue(self, criterion):
         value = criterion.get('value')
         operator = criterion.get('operator')
-        if value is None:
+        if value == None:
             if operator == "isNull":
                 return True
             elif operator == "notNull":
@@ -304,9 +304,9 @@ class CommonQuerySet(QuerySet):
     def get_criteria(self, json=dict()):
         data = json.get('data', dict())
         _data = dict()
-        if data is not None:
+        if data != None:
             for key, value in data.items():
-                if value is not None and key != 'full_name':
+                if value != None and key != 'full_name':
                     setAttr(_data, key, value)
         data = _data
         delAttr(data, 'ts')
@@ -368,40 +368,40 @@ class CommonQuerySet(QuerySet):
         ob = json.get("sortBy", [])
 
         if isinstance(distinct_field_names, tuple) or (isinstance(distinct_field_names, list)):
-            if self.alive_only is False:
-                if start is not None and end is not None:
+            if self.alive_only == False:
+                if start != None and end != None:
                     queryResult = super().filter(*args, criteria).distinct(*distinct_field_names)[start:end]
-                elif start is not None and end is None:
+                elif start != None and end == None:
                     queryResult = super().filter(*args, criteria).distinct(*distinct_field_names)[start:]
-                elif end is not None and start is None:
+                elif end != None and start == None:
                     queryResult = super().filter(*args, criteria).distinct(*distinct_field_names)[:end]
                 else:
                     queryResult = super().filter(*args, criteria).distinct(*distinct_field_names)
             else:
-                if start is not None and end is not None:
+                if start != None and end != None:
                     queryResult = super().filter(*args, criteria).filter(deleted_at__isnull=True).distinct(*distinct_field_names)[start:end]
-                elif start is not None and end is None:
+                elif start != None and end == None:
                     queryResult = super().filter(*args, criteria).filter(deleted_at__isnull=True).distinct(*distinct_field_names)[start:]
-                elif end is not None and start is None:
+                elif end != None and start == None:
                     queryResult = super().filter(*args, criteria).filter(deleted_at__isnull=True).distinct(*distinct_field_names)[:end]
                 else:
                     queryResult = super().filter(*args, criteria).filter(deleted_at__isnull=True).distinct(*distinct_field_names)
         else:
-            if self.alive_only is False:
-                if start is not None and end is not None:
+            if self.alive_only == False:
+                if start != None and end != None:
                     queryResult = super().order_by(*ob).filter(*args, criteria).distinct()[start:end]
-                elif start is not None and end is None:
+                elif start != None and end == None:
                     queryResult = super().order_by(*ob).filter(*args, criteria)[start:]
-                elif end is not None and start is None:
+                elif end != None and start == None:
                     queryResult = super().order_by(*ob).filter(*args, criteria)[:end]
                 else:
                     queryResult = super().order_by(*ob).filter(*args, criteria)
             else:
-                if start is not None and end is not None:
+                if start != None and end != None:
                     queryResult = super().order_by(*ob).filter(*args, criteria).filter(deleted_at__isnull=True)[start:end]
-                elif start is not None and end is None:
+                elif start != None and end == None:
                     queryResult = super().order_by(*ob).filter(*args, criteria).filter(deleted_at__isnull=True)[start:]
-                elif end is not None and start is None:
+                elif end != None and start == None:
                     queryResult = super().order_by(*ob).filter(*args, criteria).filter(deleted_at__isnull=True)[:end]
                 else:
                     queryResult = super().order_by(*ob).filter(*args, criteria).filter(deleted_at__isnull=True)
@@ -428,9 +428,9 @@ class CommonQuerySet(QuerySet):
             data = request.json.get('data')
             deleted = False
             for remove_field in remove_fields:
-                if delAttr(data, remove_field) is True:
+                if delAttr(data, remove_field) == True:
                     deleted = True
-            if deleted is True:
+            if deleted == True:
                 setAttr(request.json, 'data', data)
 
         self.alive_only = request.alive_only
@@ -586,7 +586,7 @@ class CommonManager(Manager):
         data = request.get_data()
         _data = data.copy()
 
-        if _data.get('parent') is not None and isinstance(_data.get('parent'), int):
+        if _data.get('parent') != None and isinstance(_data.get('parent'), int):
             setAttr(_data, 'parent_id', _data.get('parent'))
             delAttr(_data, 'parent')
 
@@ -646,7 +646,7 @@ class CommonManager(Manager):
                 for prop in propsArr:
                     _prop = data.get(prop)
 
-                    if _prop is True:
+                    if _prop == True:
                         props = TurnBitOn(props, idx)
                     else:
                         props = TurnBitOff(props, idx)
@@ -717,7 +717,7 @@ class CommonManager(Manager):
 
         _old = _old1
 
-        for field_name in [field.name for field in old._meta.fields if field._unique is True]:
+        for field_name in [field.name for field in old._meta.fields if field._unique == True]:
             num = 1
             value = None
             while True:
@@ -767,7 +767,7 @@ class CommonManager(Manager):
             field = self.get_field(key)
             if isinstance(field, list):
                 field = field[0]
-            if field is not None:
+            if field != None:
                 if isinstance(field, ForeignKey):
                     setAttr(kwargs, f'{key}_id', val)
                 else:
@@ -802,11 +802,11 @@ class CommonManager(Manager):
 
         if field:
             # if field.null:
-            if field is None:
+            if field == None:
                 setAttr(_data, 'id', None)
                 res = _data
             else:
-                _data = {k: v for k, v in _data.items() if v is not None}
+                _data = {k: v for k, v in _data.items() if v != None}
                 res = field.related_model.objects.filter(**_data)
                 if len(res) >= 1:
                     res = res[0]
