@@ -2,10 +2,16 @@ import os
 import shutil
 
 
-def mekeDirs(name, mode=0o777, exist_ok=False):
-    os.makedirs(name=name, exist_ok=exist_ok, mode=mode)
-    if not os.path.exists(name):
-        raise Exception(f'dirs: {name} not created.')
+def mekeDirs(name, logger, mode=0o777, exist_ok=False):
+    try:
+        os.makedirs(name=name, exist_ok=exist_ok, mode=mode)
+        if not os.path.exists(name):
+            logger.error(f'dirs: {name} not created.')
+            return False
+        return True
+    except FileNotFoundError:
+        logger.error(f'dirs: {name} not created.')
+        return False
 
 
 def copyTwo(src, dst, follow_symlinks=True):
