@@ -1,8 +1,10 @@
 import logging
 
 from django.db.models import PositiveIntegerField
+from django.forms import model_to_dict
 
 from isc_common.fields.code_field import CodeStrictField
+from isc_common.http.DSRequest import DSRequest
 from isc_common.models.base_ref import BaseRefHierarcy, BaseRefManager, BaseRefQuerySet
 
 logger = logging.getLogger(__name__)
@@ -12,6 +14,17 @@ class Jasper_reportsQuerySet(BaseRefQuerySet):
     pass
 
 
+def get_reports(request):
+    from reports.models.jasper_reports_users import Jasper_reports_users
+
+    request = DSRequest(request=request)
+    jasper_reports = [dict(
+        report=model_to_dict(item.report),
+        editor_identifier=item.editor_identifier,
+    ) for item in Jasper_reports_users.objects.filter(user=request.user)]
+    return jasper_reports
+
+
 class Jasper_reportsManager(BaseRefManager):
 
     @staticmethod
@@ -24,6 +37,7 @@ class Jasper_reportsManager(BaseRefManager):
             'description': record.description,
             'username': record.username,
             'password': record.password,
+            'report_id': record.report_id,
             'host': record.host,
             'port': record.port,
             'parent': record.parent.id if record.parent else None
@@ -36,6 +50,7 @@ class Jasper_reportsManager(BaseRefManager):
 
 class Jasper_reports(BaseRefHierarcy):
     path = CodeStrictField(default='/jasperserver/rest_v2/reports/')
+    report_id = CodeStrictField(null=True, blank=False)
     username = CodeStrictField(default='printer')
     password = CodeStrictField(default='printer')
     host = CodeStrictField()
